.. sushy documentation master file, created by
   sphinx-quickstart on Tue Jul 9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=================================
Welcome to Sushy's documentation!
=================================

.. include:: ../../README.rst

Features
========

* Abstraction around the SystemCollection and System resources (Basic
  server identification and asset information)
* RAID in Redfish based Systems
* Redfish Ethernet Interface
* System mappings
* System processor
* Storage management
* Systems power management (Both soft and hard; Including NMI injection)
* Changing systems boot device, frequency (Once or permanently) and mode
  (UEFI or BIOS)
* Chassis management
* OEM extension
* Virtual media management
* Session Management

Documentation
=============

.. toctree::
   :maxdepth: 1

   install/index
   contributor/index
   reference/index

* :ref:`genindex`
